cgexplore.systems\_optimisation.StructureCalculator
===================================================

.. currentmodule:: cgexplore.systems_optimisation

.. autoclass:: StructureCalculator
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~StructureCalculator.calculate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StructureCalculator.structure_function
      ~StructureCalculator.structure_output
      ~StructureCalculator.calculation_output
      ~StructureCalculator.database_path
      ~StructureCalculator.options
   
   